# 欢迎下载BeautyPrinting dev 试用版！
## 试用功能：enlighten progress bar
```python
import BeautyPrinting

BeautyPrinting.ProgressBar.enlighten_loading_bar(text='Loading', items=200, sleep=0.01, color='cyan')
```
## 非常感谢您的支持！